@@ -32,7 +32,27 @@ class CodeToolsClient:
                  log_folder: Optional[str] = None, verbose: bool = False,
                  container_name: Optional[str] = None):
         self.server_url = server_url.rstrip('/')
+        # Configure session with better connection handling
         self.session = requests.Session()
+
+        # Set connection pooling and keep-alive for better performance
+        adapter = requests.adapters.HTTPAdapter(
+            pool_connections=1,
+            pool_maxsize=1,
+            max_retries=requests.adapters.Retry(
+                total=3,
+                backoff_factor=1,
+                status_forcelist=[500, 502, 503, 504]
+            )
+        )
+        self.session.mount('http://', adapter)
+        self.session.mount('https://', adapter)
+
+        # Set keep-alive headers
+        self.session.headers.update({
+            'Connection': 'keep-alive',
+            'Keep-Alive': 'timeout=30, max=100'
+        })
         self.docker_container = None
         self.docker_image = docker_image
         self.port = port
@@ -269,18 +289,64 @@ class CodeToolsClient:
         except Exception as e:
             logging.error(f"Failed to export JSONL logs: {e}")
 
+    def _run_command_with_polling(self, data: Dict[str, Any]) -> Dict[str, Any]:
+        """Run command with polling for very long operations."""
+        import time
+
+        # Start the command with shorter initial timeout for interactive mode
+        initial_data = data.copy()
+        initial_data["timeout"] = 30  # Start with 30s to get initial response
+        initial_data["interactive"] = True
+
+        # Start the command
+        result = self._make_request("run", initial_data)
+
+        # If it completed quickly, return result
+        if result.get("success") and "timeout" not in result.get("message", ""):
+            return result
+
+        # If it's running, poll for completion
+        max_polls = data["timeout"] // 30  # Poll every 30 seconds
+        for _ in range(max_polls):
+            time.sleep(30)
+
+            # Continue the command
+            continue_result = self._make_request("run", {"command": "", "timeout": 30, "interactive": True})
+
+            # If completed, return result
+            if continue_result.get("success") and "timeout" not in continue_result.get("message", ""):
+                return continue_result
+
+            # If failed or tool error, return result
+            if not continue_result.get("success"):
+                return continue_result
+
+        # Timeout reached, kill the process
+        kill_result = self._make_request("run", {"command": "C-c", "timeout": 30, "interactive": True})
+        return kill_result
+
     def _make_request(self, endpoint: str, data: Optional[Dict[str, Any]] = None, method: str = 'POST') -> Dict[str, Any]:
-        """Make HTTP request to server."""
+        """Make HTTP request to server with dynamic timeout."""
         # Log the tool call
         self._log_tool_call(endpoint, data)
 
         try:
             url = f"{self.server_url}/api/{endpoint}"
 
-            if method == 'GET':
-                response = self.session.get(url, timeout=30)
+            # Dynamic timeout: use command timeout + buffer for long-running commands
+            if endpoint == "run" and data and "timeout" in data:
+                # Command timeout + 30 second buffer for processing
+                http_timeout = data["timeout"] + 30
+                # Cap at reasonable maximum (2 hours)
+                http_timeout = min(http_timeout, 7200)
             else:
-                response = self.session.post(url, json=data or {}, timeout=30)
+                # Default timeout for other operations
+                http_timeout = 30
+
+            if method == 'GET':
+                response = self.session.get(url, timeout=http_timeout)
+            else:
+                response = self.session.post(url, json=data or {}, timeout=http_timeout)
 
             response.raise_for_status()
             result = response.json()
@@ -398,7 +464,12 @@ class CodeToolsClient:
                 "timeout": timeout,
                 "interactive": interactive
             }
-            return self._make_request("run", data)
+
+            # For very long timeouts, use polling approach to avoid HTTP timeouts
+            if timeout > 3600:  # 1 hour
+                return self._run_command_with_polling(data)
+            else:
+                return self._make_request("run", data)
 
         # Copy docstring from actual RunTool.run_command method
         run_command_tool.__doc__ = RunTool.run_command.__doc__
