@@ -36,35 +36,23 @@ class WriteTool:
         """
         Write content to files with automatic backup and read-first safety.
 
-        WHEN TO USE:
-        - Creating new files: Scripts, configs, documentation
-        - Complete file replacement: Major rewrites, templates
-        - Use edit_file instead for: Small targeted changes, line modifications
+        USAGE:
+        - New files: Scripts, configs, documentation - write freely
+        - Replace existing: Major rewrites, templates - must read first
+        - Use edit_file for: Small targeted changes, line modifications
 
-        SAFETY REQUIREMENTS:
+        EXAMPLES:
+        write_file('new_script.py', 'print("Hello World")')  # New file
+        write_file('config.json', '{"debug": true}')  # Replace existing (after read)
+
+        SAFETY & ERRORS:
         - Must read existing non-empty files first before writing
-        - Creates automatic .backup files before overwriting
-        - Can freely write to new or empty files
-
-        LIMITATIONS:
-        - Requires read permission on existing files for safety
-        - May fail on write-protected files or directories
-        - Fixed UTF-8 encoding
-
-        BEST PRACTICES:
-        - Read existing files first to understand what you're replacing
-        - Check 'success' field before assuming write completed
-        - Consider edit_file for small changes instead of full rewrites
-
-        COMMON ERRORS:
         - "Must read file first": Read existing file content before overwriting
         - "Permission denied": Check file/directory permissions
-        - "Directory not found": Create parent directory first
 
         Args:
             file_path: Path to file to write
             content: Content to write to file
-
         Returns:
             Dict with success status and metadata
         """
